---
name: Default
about: Please always use this template
title: ''
labels: ''
assignees: ''

---

**Question?**
Please ask your question (e.g. "How do I do xyz?", "Can pybliometrics do abc"?) on StackOverflow.com and tag your question with pybliometrics.

**Bug report?**
Please state your pybliometrics version and a _complete_ code snippet to reproduce the bug.

**Feature request?**
Make sure you read the _entire_ documentation (incl. https://pybliometrics.readthedocs.io/en/stable/configuration.html and https://pybliometrics.readthedocs.io/en/stable/tips.html) so that you're not proposing what's already there
